@@ -9,6 +9,7 @@
 
 # %% Libraries
 import os
+import sys
 import zipfile
 import numpy as np
 from sklearn.tree import export_graphviz
@@ -85,8 +86,13 @@ def xgboost(model, featnames=None, num_trees=0, plottype='horizontal', figsize=(
 
     if plottype=='horizontal': plottype='UD'
     if plottype=='vertical': plottype='LR'
-    fig, ax = plt.subplots(1, 1, figsize=figsize)
-    plot_tree(model, num_trees=num_trees, rankdir=plottype, ax=ax)
+
+    try:
+        fig, ax = plt.subplots(1, 1, figsize=figsize)
+        plot_tree(model, num_trees=num_trees, rankdir=plottype, ax=ax)
+    except:
+        if _get_platform() != "windows":
+            print('[TREEPLOT] Install graphviz first: <sudo apt install python-pydot python-pydot-ng graphviz>')
 
     # Plot importance
     plot_importance(model)
@@ -152,18 +158,21 @@ def randomforest(model, featnames=None, num_trees=0, filepath='tree', export='pn
                                )
 
     # Save to pdf
-    if export=='pdf':
+    if export == 'pdf':
         s = Source.from_file(dotfile)
         s.view()
 
     # Save to png
-    if export=='png':
-        # Convert to png using system command (requires Graphviz)
-        call(['dot', '-Tpng', dotfile, '-o', pngfile, '-Gdpi=' + str(resolution)])
-        fig, ax = plt.subplots(1, 1, figsize=figsize)
-        img = mpimg.imread(pngfile)
-        plt.imshow(img)
-        plt.axis('off')
+    if export == 'png':
+        try:
+            call(['dot', '-Tpng', dotfile, '-o', pngfile, '-Gdpi=' + str(resolution)])
+            fig, ax = plt.subplots(1, 1, figsize=figsize)
+            img = mpimg.imread(pngfile)
+            plt.imshow(img)
+            plt.axis('off')
+        except:
+            if _get_platform() != "windows":
+                print('[TREEPLOT] Install graphviz first: <sudo apt install python-pydot python-pydot-ng graphviz>')
 
     return(ax)
 
@@ -190,24 +199,32 @@ def import_example(n_samples=1000, n_feat=10):
 
 # %% Get graphiz path and include into local PATH
 def _set_graphviz_path(gfile='graphviz-2.38.zip', verbose=3):
-    curpath = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'RESOURCES')
-    # filesindir = os.listdir(curpath)[0]
-    idx = gfile[::-1].find('.') + 1
-    dirname = gfile[:-idx]
-    getPath = os.path.abspath(os.path.join(curpath, dirname))
-    getZip = os.path.abspath(os.path.join(curpath, gfile))
-    # Unzip if path does not exists
-    if not os.path.isdir(getPath):
-        if verbose>=3: print('[TREEPLOT] Extracting graphviz files..')
-        [pathname, _] = os.path.split(getZip)
-        # Unzip
-        zip_ref = zipfile.ZipFile(getZip, 'r')
-        zip_ref.extractall(pathname)
-        zip_ref.close()
-        getPath = os.path.join(pathname, dirname)
+    finPath=''
+    if _get_platform()=="windows":
+        curpath = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'RESOURCES')
+        # filesindir = os.listdir(curpath)[0]
+        idx = gfile[::-1].find('.') + 1
+        dirname = gfile[:-idx]
+        getPath = os.path.abspath(os.path.join(curpath, dirname))
+        getZip = os.path.abspath(os.path.join(curpath, gfile))
+        # Unzip if path does not exists
+        if not os.path.isdir(getPath):
+            if verbose>=3: print('[TREEPLOT] Extracting graphviz files..')
+            [pathname, _] = os.path.split(getZip)
+            # Unzip
+            zip_ref = zipfile.ZipFile(getZip, 'r')
+            zip_ref.extractall(pathname)
+            zip_ref.close()
+            getPath = os.path.join(pathname, dirname)
 
-    # Point directly to the bin
-    finPath = os.path.abspath(os.path.join(getPath, 'release', 'bin'))
+        # Point directly to the bin
+        finPath = os.path.abspath(os.path.join(getPath, 'release', 'bin'))
+    else:
+        pass
+        # sudo apt install python-pydot python-pydot-ng graphviz
+        # dpkg -l | grep graphviz
+        # call(['dpkg', '-l', 'grep', 'graphviz'])
+        # call(['dpkg', '-s', 'graphviz'])
 
     # Add to system
     if finPath not in os.environ["PATH"]:
@@ -217,6 +234,18 @@ def _set_graphviz_path(gfile='graphviz-2.38.zip', verbose=3):
     return(finPath)
 
 
+def _get_platform():
+    platforms = {
+        'linux1':'linux',
+        'linux2':'linux',
+        'darwin':'osx',
+        'win32':'windows'
+    }
+    if sys.platform not in platforms:
+        return sys.platform
+    return platforms[sys.platform]
+
+
 # %% Check input model
 def _check_model(model, expected):
     modelname = str(model).lower()
